@@ -221,10 +221,20 @@ Value::Value(const GValue* castitem)
 
 Value& Value::operator=(const Value& src)
 {
+  if(this == &src)
+    return *this;
+
+  //Avoid doing anything if no change is necessary:
+  if(gobj() == src.gobj())
+    return *this;
+
   // Unset current value, if any
-  if(G_IS_VALUE(gobj())) g_value_unset(gobj());
+  if(G_IS_VALUE(gobj()))
+    g_value_unset(gobj());
+
   // Set new value, if any
-  if(G_IS_VALUE(src.gobj())) init(src.gobj());
+  if(G_IS_VALUE(src.gobj()))
+    init(src.gobj());
 
   return *this;
 }
@@ -289,6 +299,8 @@ const guchar* Value::get_binary(long& size) const
 
 void Value::set(const guchar* val, long size)
 {
+  value_reinit(gobj(), GDA_TYPE_BINARY);
+  
   GdaBinary gdabinary;
   gdabinary.data = const_cast<guchar*>(val);
   gdabinary.binary_length = size;
@@ -416,6 +428,16 @@ void Value::set(gushort val)
   gda_value_set_ushort(gobj(), val); 
 }
 
+glong Value::get_long() const
+{
+  return g_value_get_long(const_cast<GValue*>(gobj()));
+}
+
+void Value::set(glong val)
+{
+  g_value_set_long(gobj(), val); 
+}
+
 gulong Value::get_ulong() const
 {
   return g_value_get_ulong(const_cast<GValue*>(gobj()));
